<!--
Thank you for submitting a Feature Request!

If you want to run ideas by the maintainers and the Eigen community first, 
you can chat about them on the [Eigen Discord server](https://discord.gg/2SkEJGqZjR).
-->

### Describe the feature you would like to be implemented.

### Why Would such a feature be useful for other users?

### Any hints on how to implement the requested feature?

### Additional resources
